@@ -10,11 +10,11 @@
 #define __REPOSITORY_STUB__
 
 #include <dcopstub.h>
-#include <qobject.h>
 #include <dcopobject.h>
+#include <qobject.h>
 
 
-class Repository_stub : virtual public DCOPStub
+class KDE_EXPORT Repository_stub : virtual public DCOPStub
 {
 public:
     Repository_stub( const QCString& app, const QCString& id );
